"""

Xerenity python library
"""

__version__ = "0.1.3"
__author__ = 'Xerenity'

from xerenity.connection.db import Connection
from xerenity.search.series import Series


class Xerenity:

    def __init__(self, username, password):
        self.username: username
        self.password = password
        self.conn = Connection()
        self.conn.login(username=username, password=password)
        self.series: Series = Series(connection=self.conn)



class Series:

    def __init__(self, connection):
        self.sup = connection

    def portfolio(self):
        """

        Function para obtener el portafolio completo de series que ofrece Xerenity
        :return: [{{'source_name': str, 'grupo': str, 'description': str, 'display_name':str}]
        """
        return self.sup.get_all_series()

    def search(self, ticker):
        """

        Dado el nombre de una serie, retorna los valores almacenados por Xerenity
        Para obtener el nombre de la serie, puede vistar la pagina web o utilizar la funcion portafolio
        :param ticker:
        :return: [{"time":"fecha","value":valor de la serie en la fecha}]
        """
        return self.sup.read_serie(ticker=ticker)



from supabase import create_client, Client
from supabase.client import ClientOptions


class Connection:

    def __init__(self):
        url: str = "https://tvpehjbqxpiswkqszwwv.supabase.co"
        key: str = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6InR2cGVoamJxeHBpc3drcXN6d3d2Iiwicm9sZSI6ImFub24iLCJpYXQiOjE2OTY0NTEzODksImV4cCI6MjAxMjAyNzM4OX0.LZW0i9HU81lCdyjAdqjwwF4hkuSVtsJsSDQh7blzozw"
        self.supabase: Client = create_client(
            url, key,
            options=ClientOptions(
                auto_refresh_token=False,
                postgrest_client_timeout=40,
                storage_client_timeout=40,
                schema="xerenity",
            ))

    def login(self, username, password):
        """

        Inicia sesion con el servidor de xerenity

        :param username: Usuario
        :param password: contrasena
        :return:
        """
        try:
            data = self.supabase.auth.sign_in_with_password(
                {
                    "email": username,
                    "password": password}
            )
            return data

        except Exception as er:
            return str(er)

    def get_all_series(self):
        """

        :return:
        """
        try:
            data = self.supabase.from_('search_mv').select('source_name,grupo,description,display_name').execute().data
            return data
        except Exception as er:
            return str(er)

    def read_serie(self, ticker: str):
        """

        Funcion que retorna los valores de la serie deseada, si la serie no es encontrada
        se retorna un contenedor vacio

        :param ticker: Identificador unico de la serie a leer
        :return:
        """
        try:
            data = self.supabase.rpc('search', {"ticket": ticker}).execute().data
            if 'data' in data:
                return data['data']
            return data
        except Exception as er:
            return str(er)



from setuptools import setup, find_packages

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='xerenity',
    version='0.1.6',
    description='Python package for xerenity',
    url='https://xerenity.vercel.app/login',
    author='Andres Velez',
    author_email='svelez@xerenity.co',
    license='BSD 2-clause',
    install_requires=['supabase>=2.4.4'],
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.5',
    ],
)
